@@ -17,15 +17,15 @@ def main():
 
 
 @fastapi.command()
-@click.option('--is_only_orm', is_flag=False)
+@click.option('--only', is_flag=True, help="only generate orm")
 @click.option('--db_host', default="localhost")
 @click.option('--db_name', default='test')
 @click.option('--db_user', default="test")
 @click.option('--db_pswd', default="test")
-def orm(db_name, db_host, db_user, db_pswd, is_only_orm):
+def orm(db_name, db_host, db_user, db_pswd, only):
     app = MainApp()
     app.create_app_with_orm(
-        db_name=db_name, db_pswd=db_pswd, db_host=db_host, db_user=db_user, is_only_orm=is_only_orm
+        db_name=db_name, db_pswd=db_pswd, db_host=db_host, db_user=db_user, is_only_orm=only
     )
 
 
